==> gprs-converter-1.5.3-sources.jar: com/xdja/gprsconverter/convert/ChangePwdProtocolConvert.java <==
package com.xdja.gprsconverter.convert;

import android.text.TextUtils;

import com.xdja.gprsconverter.protocol.ChangePwdRequest;
import com.xdja.gprsconverter.protocol.ChangePwdResponse;

/**
 *
 * Created by Guojie on 2017/8/31.
 */

public class ChangePwdProtocolConvert implements ConvertInterface<ChangePwdRequest, ChangePwdResponse> {

    @Override
    public String convertBean2XML(ChangePwdRequest changePwdRequest) {
        StringBuilder sb = new StringBuilder();
        sb.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
        sb.append("<Root>");
        if (!TextUtils.isEmpty(changePwdRequest.getAppKey())){
            sb.append("<AppKey>" + changePwdRequest.getAppKey() + "</AppKey>");
        }
        if (!TextUtils.isEmpty(changePwdRequest.getReqDigest())){
            sb.append("<ReqDigest>" + changePwdRequest.getReqDigest() + "</ReqDigest>");
        }
        if (!TextUtils.isEmpty(changePwdRequest.getPoliceNo())){
            sb.append("<PoliceNo>" + changePwdRequest.getPoliceNo() + "</PoliceNo>");
        }
        sb.append("<ReqType>" + changePwdRequest.getReqType() + "</ReqType>");
        sb.append("<SessionID>" + changePwdRequest.getSessionID() + "</SessionID>");
        sb.append("<ValidateType>" + changePwdRequest.getValiDataType() + "</ValidateType>");
        sb.append("<ValidateValue>" + changePwdRequest.getValiDataValue() + "</ValidateValue>");
        sb.append("<NewPassword>" + changePwdRequest.getNewPwd() + "</NewPassword>");
        sb.append("<OldPassword>" + changePwdRequest.getOldPwd() + "</OldPassword>");
        sb.append("</Root>");
        return sb.toString();
    }

    @Override
    public ChangePwdResponse convertXML2Bean(String string) {

        if (!TextUtils.isEmpty(string) && string.startsWith(ChangePwdResponse.SUCCESS)) {
            return new ChangePwdResponse(true);
        } else {
            return new ChangePwdResponse(false);
        }
    }
}

==> gprs-converter-2.1.1-sources.jar: com/xdja/gprsconverter/convert/ChangePwdProtocolConvert.java <==
package com.xdja.gprsconverter.convert;

import android.text.TextUtils;

import com.xdja.gprsconverter.extension.ErrorInfoExtension;
import com.xdja.gprsconverter.protocol.ChangePwdRequest;
import com.xdja.gprsconverter.protocol.ChangePwdResponse;

/**
 * Created by Guojie on 2017/8/31.
 */

public class ChangePwdProtocolConvert implements ConvertInterface<ChangePwdRequest, ChangePwdResponse> {

    @Override
    public String convertBean2XML(ChangePwdRequest changePwdRequest) {
        StringBuilder sb = new StringBuilder();
        sb.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
        sb.append("<Root>");
        if (!TextUtils.isEmpty(changePwdRequest.getAppKey())) {
            sb.append("<AppKey>" + changePwdRequest.getAppKey() + "</AppKey>");
        }
        if (!TextUtils.isEmpty(changePwdRequest.getReqDigest())) {
            sb.append("<ReqDigest>" + changePwdRequest.getReqDigest() + "</ReqDigest>");
        }
        if (!TextUtils.isEmpty(changePwdRequest.getPoliceNo())) {
            sb.append("<PoliceNo>" + changePwdRequest.getPoliceNo() + "</PoliceNo>");
        }
        sb.append("<ReqType>" + changePwdRequest.getReqType() + "</ReqType>");
        sb.append("<SessionID>" + changePwdRequest.getSessionID() + "</SessionID>");
        sb.append("<ValidateType>" + changePwdRequest.getValiDataType() + "</ValidateType>");
        sb.append("<ValidateValue>" + changePwdRequest.getValiDataValue() + "</ValidateValue>");
        sb.append("<NewPassword>" + changePwdRequest.getNewPwd() + "</NewPassword>");
        sb.append("<OldPassword>" + changePwdRequest.getOldPwd() + "</OldPassword>");
        sb.append("</Root>");
        return sb.toString();
    }

    @Override
    public ChangePwdResponse convertXML2Bean(String string) {
        ChangePwdResponse changePwdResponse = new ChangePwdResponse();
        changePwdResponse.setResponse(string);
        ErrorInfoExtension.parseErrorMsg(string);
        if (ErrorInfoExtension.isError) {
            changePwdResponse.setResult(false);
            changePwdResponse.setErrorCode(ErrorInfoExtension.code);
            changePwdResponse.setErrorMessage(ErrorInfoExtension.message);
        } else {
            changePwdResponse.setResult(true);
            if (!TextUtils.isEmpty(string) && string.startsWith(ChangePwdResponse.SUCCESS)) {
                changePwdResponse.setSuccess(true);
            } else {
                changePwdResponse.setSuccess(false);
            }
        }
        return changePwdResponse;
    }
}
